function agents = agencyInput(agents,win,frame,v)
% agents = agencyInput(agents,win,frame,v)
%
% Deals new F0s to existing or new agents
%

numAgents=length(agents);
numF0s=length(win.f0);

logFthrs=log(2^(1/12)); % log of semitone
egyThrs=0.01;

chosenInd=[];
featSleepThrs=0.8;

if ~(isstruct(win.f0))
  %% all agents die 
  for a=1:numAgents
    if ~(agents(a).alive), continue; end
    agents(a).death=frame;
    agents(a).alive=0;
    agents(a).age=agents(a).death-agents(a).birth;
  end
  return; 
end

for a=1:numAgents
  if (~agents(a).alive), continue;end

  %% find closest f0 for this agent
 
  minVal=inf;
  minInd=-1;
  for f=1:numF0s
      
      featDiff=abs(log(win.f0(f).freq) - log(agents(a).lastFreq+eps));

      if(featDiff<minVal)
   	minVal=featDiff;
	minInd=f;
      end
  end

  % think about death
  
  chosenFreq=win.f0(minInd).freq;
  
  if (~(isstruct(win.f0))|(abs(log(chosenFreq) - log(agents(a).lastFreq))) > logFthrs)
    % DIE!
    agents(a).death=frame;
    agents(a).alive=0;
    agents(a).age=agents(a).death-agents(a).birth;
  else
    % now save index of best f0  
    agents(a).trace=[agents(a).trace minInd];
    age=frame-agents(a).birth;
    agents(a).age=age+1;
    agents(a).meanEnergy=(age*agents(a).meanEnergy+win.f0(minInd).energy)/(age+1);
    agents(a).lastFreq=win.f0(minInd).freq;
    agents(a).valid=1;    
    chosenInd=[chosenInd minInd];
  end
end			

% find feature Vects that have no agent yet
newInd=setdiff(1:numF0s, chosenInd);

% and create new agents for them
for n=1:length(newInd)
  agents(numAgents+n).birth=frame;
  agents(numAgents+n).alive=1;
  agents(numAgents+n).trace(1)=newInd(n);
  agents(numAgents+n).meanEnergy=win.f0(newInd(n)).energy;
  agents(numAgents+n).age=1;
  agents(numAgents+n).startFreq=win.f0(newInd(n)).freq;
  agents(numAgents+n).lastFreq=win.f0(newInd(n)).freq;
end
