function snd = analyzeAll(snd)
% function snd = analyzeAll(snd)
%
% input snd: input of audio data prepared by prepareData()
% output snd: analysis data, F0s and agents added to struct

global opt sw

%% all-data matrices 
snd.an.Spec		= zeros(snd.var.fLen, snd.var.tLen);
snd.an.Ceps		= zeros(opt.cepWinSize, snd.var.tLen);
snd.an.SpecLiftered	= zeros(snd.var.fLen, snd.var.tLen);

%% display masks
snd.an.masks.F0		= zeros(snd.var.fLen, snd.var.tLen); % F0s
snd.an.masks.FirstF0	= zeros(snd.var.fLen, snd.var.tLen); % strongest F0s
snd.an.masks.Overlap	= zeros(snd.var.fLen, snd.var.tLen); % overlapping partials
snd.an.masks.CasaAmp	= zeros(snd.var.fLen, snd.var.tLen); % L/R Amplitude Difference of recognized F0's
snd.an.masks.CasaPhi	= zeros(snd.var.fLen, snd.var.tLen); % L/R Phase Difference of recognized F0's

snd.reSynth=zeros(length(snd.mono)+2*opt.windowSize,1);

% init agency
snd.agents=[];
snd.agents(1).birth=0;
snd.agents(1).alive=0;
snd.agents(1).valid=0;
snd.agents(1).lastFreq=1;

for frame = 1:snd.var.tLen,
   %status output
   if (mod(frame,round(snd.var.tLen/5))==0), disp('.');end

   %frame
   win.stereo = snd.stereo((frame-1)*opt.windowHop+1:(frame-1)*opt.windowHop+opt.windowSize,:);
   
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   %% main signal analysis
     
   win = analyzeWin(win,snd.var);

   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   %% collect data
   
   snd.an.Spec(:,frame)=win.spec;
   snd.an.Ceps(:,frame)=win.ceps(1:opt.cepWinSize);

   %% for model generation only
   if(sw.GetSpecLiftered),  snd.an.SpecLiftered(:,frame)=win.specLiftered; end
       
   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   %% build masks for output with showSpec()
   if (isstruct(win.f0))
 	  %% F0   
	   for j=1:length(win.f0)
	        snd.an.masks.F0(win.f0(j).ind,frame)=(win.f0(j).energy+1)/2;
	   end  
	   
	   if (length(win.f0)>0), snd.an.masks.FirstF0(win.f0(1).ind,frame)=1; end
	
	   snd.an.masks.Overlap(win.ovlpInd+(frame-1)*snd.var.fLen)=1;
	
	   %% CASA
	   for j=1:length(win.f0)
	     snd.an.masks.CasaAmp(win.f0(j).ind,frame)=1+(6+win.f0(j).dA)/12; % get data between [0,1]+1
	     snd.an.masks.CasaPhi(win.f0(j).ind,frame)=win.f0(j).dPhi;
	     
	   end  

	   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
	   % synthesize a reference sound if wanted
	   if(sw.SynthAll)
	     if (length(win.f0)>0)
	     win.reSynth=sum(synthSound(win.f0(:).freq, win.f0(:).harmAmp, ones(opt.windowSize,length(win.f0))),2);
	     win.reSynth=0.95*win.reSynth/max(win.reSynth);
	     snd.reSynth((frame-1)*opt.windowHop+1:(frame-1)*opt.windowHop+opt.windowSize)=snd.an.reSynth((frame-1)*opt.windowHop+1:(frame-1)*opt.windowHop+opt.windowSize)+win.reSynth.*(opt.sWindow).^2;
	    end
	   end
	   %
   	   %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
   
     end %if f0 found	 
	 
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     %% pass features to agency
	 
     snd.agents = agencyInput(snd.agents, win, frame, snd.var);
   
     %%
     %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     

   % delete fields to safe memory
   win=rmfield(win,{'stereo', 'sig','specRight','specLeft','spec','specLiftered','specHPLiftered','specWhite'});

   snd.an.wins(frame)=win;
	 
end

%% all agents alive must die now
for a=1:length(snd.agents)
  if (snd.agents(a).alive)
     % needs to be done like this because it could be that
     % no f0s were found the last frames so agents are not yet dead but don't last
     % till the end
    snd.agents(a).death=snd.agents(a).birth+snd.agents(a).age;
  end
end

if(sw.SynthAll)
  snd.reSynth=0.95*snd.reSynth/max(snd.reSynth);
  wavwrite(snd.reSynth,opt.samplFreq,'allSynth.wav');
end
