function win = analyzeWin(win,v,level)
% win = analyzeWin(win, v [,level])
% 
% main signal processing routine
% 
% level 1: only spec & ceps [default]
% level 2: all raw features
% level 3: all raw & advanced features
%
% output win: struct of all necessary data 
 
global opt sw
 
if (nargin<3), level=5 ;end

win.f0=[];

%windowing
win.stereo=opt.aWindow*ones(1,2).*win.stereo;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% STEREO Signal Analysis

win.specLeft=fft(win.stereo(:,1), opt.fftSize);
win.specRight=fft(win.stereo(:,2), opt.fftSize);
% cut
win.specLeft=win.specLeft(1:opt.fftSize/2);
win.specRight=win.specRight(1:opt.fftSize/2);

%% monauralize
win.sig=sum(win.stereo,2);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% MONO Signal Analysis - Raw Features

%%% Spectrum
win.spec=win.specLeft+win.specRight;

%%% Cepstrum
win.ceps=rceps(win.sig);
win.ceps=win.ceps(1:opt.windowSize/2); % rceps independent of fftSize!!!

if (level>1)
  %%% ceps liftered spectrum (leave out first ceps coeff! its sqrt of energy)
  win.specLiftered = 2*20/log(10)*real(fft([1; win.ceps(2:opt.cepWinSize)],opt.fftSize)); 
  % cut
  win.specLiftered = win.specLiftered(1:length(win.spec));
  
  win.specHPLiftered = 2*20/log(10)*real(fft([ zeros(opt.cepWinSize,1); win.ceps(opt.cepWinSize+1:end)],opt.fftSize));  
  win.specHPLiftered = win.specHPLiftered(1:length(win.spec));
  %%% whitened spectrum
  win.specWhite = win.spec./(10.^(1/20*win.specLiftered));
  
  %%% acf normalized white
  win.ACF = acf(win.specWhite');
  win.ACF = win.ACF/win.ACF(1);

  %%% Cepstrally Enhanced Autocorrelation Function  
  win.CEACF=ceacf(v,win.specWhite,abs(win.ceps));
  
end    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% Advanced Features

if (level>2)
    %%% F0 Extraction
  win.f0=getF0s(v, win.CEACF, win.spec);
  win.f0=getHarmonics(v, win.f0,win.spec);
  
    %%% acf of harmonics
  for i=1:length(win.f0)
    if (length(win.f0(i).harmAmp)<1), win.f0(i).harmNACF=zeros(1,5);continue;end
    win.f0(i).harmNACF=acf(abs(win.f0(i).harmAmp(1:3)));
    win.f0(i).harmNACF=win.f0(i).harmNACF/win.f0(i).harmNACF(1);
  end

    % energy as part of total signal energy
  dealer=num2cell([win.f0.energyAbs]/sum(abs(win.spec).^2));
  [win.f0.energy]=deal(dealer{:});  
 
    % define to keep constant struct
  win.ovlpInd=[];
  win.ovlpFreq=[];
    % forget the ones with too little Energy  
  ind=find([win.f0.energy]>opt.thrsEnergy);
    % sort F0s by energy descending
  [tmp, ord]=sort(-[win.f0(ind).energy]);
  
  tmp=win.f0;
  win=rmfield(win,'f0'); 
  for i=1:length(ind)
     win.f0(i)=tmp(ind(ord(i)));
  end
  
  if (length(ind)==0) 
    % no f0
    win.f0=[]; 
    win.ovlpInd=[];
    win.ovlpFreq=[];
    disp('empty win')
    return; 
  end

  [win.f0, win.ovlpInd]=detectOverlaps(v, win.f0);
  win.ovlpFreq=v.f(win.ovlpInd);
  
    %%% CASA
  win = getSpacialDist(v, win);

end

