function myceacf = ceacf(var, spec, ceps)
% ceacf = ceacf(var, spec, ceps)
% 
% Cepstrally Enhanced Autocorrelation Function
% inputs:
%   var: snd.var, parameters of audio data 
%   spec: spectrum to use (should be a whitened spectrum)
%   ceps: cepstrum for same window

global opt sw

myacf=acf(abs(spec))';

 % kill everything under lowestF 
lowInd=floor(opt.lowestF/var.fMax*var.fLen);
myacf(1:lowInd)=zeros(1,lowInd);

 % invert quefrency axis to get cepstrum on frequency axis 
invInd=round((1/opt.highestF*opt.samplFreq)):round((2/opt.lowestF*opt.samplFreq));

 % kill too big inds
toobigInd=find(invInd>size(ceps,1));
invInd=setdiff(invInd, invInd(toobigInd));

thisCep=ceps(invInd);
thisCep=thisCep/max(thisCep);

qf0=getQ0s(var,thisCep,0.3);

  % compensate shift
inds=[qf0.ind]+round((1/opt.highestF*opt.samplFreq))-1;
amps=[qf0.a];

peakWidth=7;
peak=winFct(peakWidth);
mycep=zeros(size(spec));

peakInd = round(1./var.cepAx(inds)*var.fLen/var.fMax);
peakInd*var.fMax/var.fLen;
%F0ind


for i=1:length(inds)
     if (inds(i)>ceil(peakWidth/2))
       mycep(peakInd(i)-floor(peakWidth/2):peakInd(i)+floor(peakWidth/2))=mycep(peakInd(i)-floor(peakWidth/2):peakInd(i)+floor(peakWidth/2))+peak*amps(i);
     end
end

% limit to 1
ind=find(mycep>1);
mycep(ind)=ones(size(ind));

myceacf=myacf.*(mycep+0.02);
myceacf=myceacf/max(myceacf);

if(sw.DebugMode==1)

	figure(42)
	subplot(511)
	 plot(var.f,abs(spec));
	 axis([0 1000 0 max(abs(spec))]);
	 xlabel('f')
	 ylabel('|F(f)|')
	 title('whitened fft-spectrum')
	subplot(512)
	 plot(var.f,myacf/max(myacf));
	 axis([0 1000 0 1]);	 
	 xlabel('f')
	 ylabel('acf')
	 title('normalized autocorrelation of spectrum')
	subplot(513)
	 plot(1./var.cepAx,ceps)
	 axis([0 1000 0 1]);
	 line([1./var.cepAx(inds);1./var.cepAx(inds)],[zeros(size(inds));abs(ceps(1))*ones(size(inds))],'LineStyle', ':','Color',[.5 .5 .5])
	 xlabel('1/T')
	 ylabel('|Ceps|')
	 title('real cepstrum with detected peaks')
	subplot(514)
	 plot(var.f,mycep);
	 axis([0 1000 0 1]);
	 xlabel('1/T')
	 ylabel('CEF')
	 title('Cepstral Enhancement Function')
        subplot(515)
	 plot(var.f,myceacf);
	 axis([0 1000 0 1]);
	 xlabel('f')
	 ylabel('CEACF')
	 title('CEACF')
	
	%% print to file
	set(gcf, 'PaperPosition', [1 3 8 10]);
	print -depsc2 ceacf.eps
	
end
