function [f0, overlapInd] = detectOverlaps(v, f0, tol)
%[f0, overlapInd] = detectOverlaps(v, f0, tol)
%
% inputs: 
%   v: snd.var, audio parameters
%   f0: struct array of f0s with harmonics
%   tol: tolerance, +-# of freq-bins (default: 1)
%
% adds fields to f0:
%   f0(.).harmInds
%   f0(.).reliab
%

if nargin<3, tol=1 ; end 

global opt

harmTable=zeros(v.fLen,length(f0));
harmTableDil=zeros(v.fLen,length(f0));

for i=1:length(f0)
    
    f0(i).harmInds=round(f0(i).harmFreqs/v.fMax*v.fLen);
    ind=(i-1)*v.fLen+f0(i).harmInds';
 
    if (length(ind)==0), continue;end
    % "dilate" indexes with tolarance width
    ind2=[];
    for j=-tol:tol
        ind2=[ind2; ind+j];
    end

      %delete indexes exceeding size
    kill=find(ind2<1 | ind2>length(harmTableDil(:)));
    ind2(kill)=ind(1)*ones(size(kill)); %just replace with existing index

      %ind2
    harmTableDil(ind2)=ones(size(ind2));
    harmTable(ind)=ones(size(ind));
end
overlapInd=find(sum(harmTableDil,2)>1);
overlapMask=zeros(v.fLen,1);
overlapMask(overlapInd)=ones(size(overlapInd));
overlapInd=find(overlapMask & sum(harmTable,2));

who=harmTable(overlapInd,:);

% now weight reliability for each harmonic and each f0
% the enrgy of overlappers is taken as negative influence to reliability
% this criterium is not very reliable itself!!  

energies=diag([f0.energy]);
harmTablDilWeight=harmTableDil * energies;
for i=1:length(f0)
  f0(i).harmInds;
  others=setdiff(1:length(f0),i);
  ovlpEnergy=sum(harmTablDilWeight(f0(i).harmInds,others),2);
  f0(i).reliab=f0(i).energy./(f0(i).energy + ovlpEnergy);
end
