function sel = evalSelect(snd, instModels, classificType)
%
% lets you choose a time slot for further evaluation
% run showSpec before

if (nargin<3), classificType='GMM';end

global opt
global plotLineOrder plotDotOrder
global sel

v=snd.var;

evalNum=1;
sel.specFeat = [];
sel.tempFeat = [];


while 1    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    % select a timeslot
    figure(1)
    [tt,ff]=ginput(1);
    TSel=round(tt/v.tMax*v.tLen+0.5)
    if TSel < 1, TSel=1; end
    if TSel > v.tLen, TSel=v.tLen; end
    FSel=round(ff/v.fMax*v.fLen+0.5);
    if FSel < 1, FSel=1; end
    if FSel > v.fLen, FSel=v.fLen; end

    %sel.TSel(evalNum)=TSel;
    %sel.FSel(evalNum)=FSel;
    %%
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    win=[];
     
    win.stereo = snd.stereo((TSel-1)*opt.windowHop+1:(TSel-1)*opt.windowHop+opt.windowSize,:);
 
    win=analyzeWin(win,v,4);
    
    % synthesize a reference sound
    win.reSynth=sum(synthSound([win.f0.freq], {win.f0.harmAmp}, ones(opt.windowSize,length(win.f0))),2);
    win.reSynth=0.95*win.reSynth/max(win.reSynth);
    %selSound=sum(synthSound(wF0, wHarmAmp, ones(1*samplFreq,length(wF0))),2);
    %selSound=0.95*selSound/max(selSound);
    %wavwrite(selSound,samplFreq,'selSynth.wav');
    p = com.mathworks.toolbox.audio.JavaAudioPlayer(win.reSynth, opt.samplFreq, 16);
    p.play;

     %sound(selSound,samplFreq);
    

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% harmonic computation output

    figure(2)
    subplot(411) % Spectrum
        plot(v.f,20*log10(abs(win.spec)))
        title(strcat('timeslot=', int2str(TSel)))
        axis([0 v.fMax -100 50 ]);
        %plot detected harmonics
	
        for i=1:length(win.f0)
            line([win.f0(i).harmFreqs;win.f0(i).harmFreqs],[-100*ones(size(win.f0(i).harmFreqs)); 20*log10(abs(win.f0(i).harmAmp))],'Color',[.5 .5 .5]);
        end        
        %mask overlapping harmonics
        line([win.ovlpFreq';win.ovlpFreq'],[-100*ones(size(win.ovlpFreq')); 50*ones(size(win.ovlpFreq'))],'LineStyle', '--','Color',[1 .7 0],'LineWidth',2);
             
        
    subplot(412) % ACF
        plot(v.f,win.ACF)
        axis([0 v.fMax 0 1]);
        title('normalized acf')
    subplot(413) % CEACF
        plot(v.f,win.CEACF)
        axis([0 v.fMax 0 1]);
        title('normalized ceacf')
        % indicate thresold
        line([0;v.fMax],[opt.thrsF0;opt.thrsF0], 'LineStyle', '--','Color',[1 .5 0])	
    subplot(414) % cepstrum
        %cepAx=0:1/samplFreq:1/lowestF-1/samplFreq; 
        plot(v.cepAx, abs(win.ceps))
        axis([0 1/opt.lowestF 0 abs(win.ceps(1))]);
        title('cepstrum');
        % indicate cepWinSize
        line([v.cepAx(opt.cepWinSize);v.cepAx(opt.cepWinSize)],[0 abs(win.ceps(1))],'LineStyle', '--','Color',[1 .5 0])
        % indicate periodicity of F0s
        line([1./[win.f0.freq];1./[win.f0.freq]],[zeros(size([win.f0.freq])); abs(win.ceps(1))*ones(size(win.f0))],'LineStyle', ':','Color',[.5 .5 .5])
        
    subplot(411) %draw cepstral liftered spectrum into spectrum
        hold on 
       
        plot(v.f,win.specLiftered,'k')
        hold off

    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% Model classification output
    
    % decide which F0 was selected
    [waste, F0indSel]=min(abs([win.f0.ind]-FSel));
    
    win.f0(F0indSel).freq
    
 
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% Agent Info output
    
    figure(66) 
    hold off
    ind=[];
    for a=1:length(snd.agents)  
       % skip if agent already dead or invalid
      if (snd.agents(a).death<=TSel), continue; end 
      if (~snd.agents(a).valid), continue; end 
      adr=TSel-snd.agents(a).birth+1;
       % skip if agent isn't born yet
      if(adr<=0), continue; end
      chosenF0ind=snd.agents(a).trace(adr);
       % is it near my selected frq?
      if (abs(FSel-snd.an.wins(TSel).f0(chosenF0ind).ind)>10), continue; end
       %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
       % this is a good agent
       % get trajectory
      age=TSel-snd.agents(a).birth+1;
      trace=snd.agents(a).trace;
       % his f0's
      clear f0s
      for i=1:length(trace)
        f0s(i)=snd.an.wins(TSel-age+i).f0(trace(i));
      end
      timeInd=snd.agents(a).birth:snd.agents(a).death-1;

      selFeat = getAgentFeatures(snd,snd.agents(a),instModels.specEnv,instModels.harmEnv);
       %save in global var
      sel.specFeat=[sel.specFeat selFeat.vect.F0];
      sel.tempFeat=[sel.tempFeat selFeat.vect.temp];

      selFeat = normalizeFeat(selFeat,instModels);
      
    
      figure(66)
      plot(v.t(timeInd),[f0s.freq]) %, plotLineOrder(1+mod(i,size(plotLineOrder,1)),:));
	axis xy;
    	axis([0 v.tMax 0 1000]);
	hold on
      % plot some note features
      figure(67)
	subplot(511)
	  plot(timeInd,[f0s.energyAbs])
	  title('f0.energyAbs')
	subplot(512)
	  plot(timeInd,selFeat.vect.F0')
	  title('f0-features')
		legend(selFeat.names.F0)
	subplot(513)
	  plot(timeInd,[f0s.a])
	  title('f0.a')
	subplot(514)
 	  [startAmp, stopAmp]=widenAgentAmp(v,snd.agents(a),snd.an.Spec,4,4);
 	  wideAmp=cat(2,startAmp, [f0s.a],stopAmp);
	  plot(wideAmp)
	  title('widened f0.a')
        subplot(515)
	  
 	 % plot([f0s.harmAmp(2:5)])
	 % title('f0.freq')
      %%
      selAgent=snd.agents(a);
      break; %right now only one agent gets plotted
    end
    figure(66)	    
    axis xy;
    axis([0 v.tMax 0 1000]);
	
    hold off 


    %%%%%%%%%%%%%%%%%%%%%%%%%%
    %% classify agent
    [instInd, instName, data]=classifyAgent(snd,selAgent,instModels,classificType)
    %data.specLhd
    %data.tempLhd
    %data.specDecisionValue
    %disp(strvcat('NN output:',num2str(data.lhd)))

	%figure(69)
	%  plot(data.specLhd')
	%legend(instModels.names)

    %%%%%%%%%%%%%%%%%%%%%%%%%%%
    %% plot GMM with feature
    %feat = getAgentFeatures(snd,selAgent,instModels.specEnv);
    %evalGMM(instModels, selFeat, data)


  evalNum=evalNum+1;
end
