function mo = featureExt(sig,winlen,win,shift,feat,numpar)

%  merkmalsextraktion extrahiert das Merkmal 'feat' von input signal 'sig'.
%                     'shift'    ist der Frame-Shift in Anz. Samples
%		      'win'      enthaelt das zu verwendende Fenster 
%                                (zb. Hamming)
%                     'winlen'   Laenge des Fensters 
%                     'mo' is die Matrix mit den extrahierten Merkmalen
%                     'numpar'   Laenge des Merkmalsvektors = Anzahl Parameter
%
%                      Folgende Merkmale koennen extrahiert werden
%
%                      spc   :    2*numpar-FFT-Spektrum
%                      cep   :    cepstrale Koeffizienten
%                      cps   :    cepstral geglaettetes Spektrum
%                                 (numpar ist hier die Anzahl Koeff. des 
%                                   cepstralen Lifters nicht der Spektrums. Das
%				   Spektrum selbst hat soviel Punkte wie die
%				   gewahlte Fensterlaenge. 
%		       lpc   :    LPC-Koeffizienten
%		       lps   :    LPC-Spektrum
%		       aut   :    Autokorrelations-Koeffizienten
%
%                                                        H.-P. Hutter/97
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Pruefung der Anzahl Parameter

if nargin >= 4
    if isempty(shift)
        shift = fix(length(win)/2);
    end
else
    shift = fix(length(win)/2);
end


sig = sig(:);           % Kolonnenvektor erzeugen
siglen = length(sig);   % Laenge des Signals
if siglen < winlen      % Falls Signal kuerzer als Fensterlaenge -> mit 0en 
   sig(winlen)=0; siglen=winlen; %  fuellen
end
fidx = 1:winlen;        % Anzahl Werte pro Merkmalsvektor

% Anzahl Frames berechnen

ncol = fix((siglen-(winlen-shift))/shift);  % nur volle frames
tidx = 1:ncol;      % Framenummern

% Startindex im Signal fuer jedes Frame berechnen

colindex = 1 + (0:ncol-1)*shift;

% Groesse der Merkmals-Matrix festlegen

if (feat == 'cps') | (feat == 'lps')            
                            % bei cepstral geglaettetem oder lpc spektrum: 
  mo = zeros(winlen,ncol);  % laenge des merkmalvektors = winlen
else
  mo = zeros(numpar,ncol);
end


% Eigentliche Merkmalsextraktion

for frame = 1:ncol,
   x = sig(colindex(frame):colindex(frame)+winlen-1);  % frame ausschneiden
   wx = x.*win;                % Signal fenstern
                               % Gewuenschtes Merkmal berechnen:
   if feat == 'cep'            % cepstrale koeffizienten
     cep = rceps(wx);
%     cep(1) = 0;
     mo(:,frame) = cep(1:numpar);
   elseif feat == 'lpc'        % lpc-koeffizienten (=pradiktor-koeff)
     [A,G,ar,mo(:,frame)] = autolpc(wx,numpar);
   elseif feat == 'aut'        % autokorrelations-koeff
     [A,G,mo(:,frame),ac] = autolpc(wx,numpar);
   elseif feat == 'lps'        % lpc-spektrum
     [A,G,ar,a] = autolpc(wx,numpar);
     B = zeros(size(A));
     B(1) = 1;
     [HH,W] = freqz(B,A,2*winlen,'whole');
     tmp = 20*log10(abs(HH));            
     mo(:,frame) = tmp(1:winlen);
   elseif feat == 'spc'        % fft-spektrum
      tmp = 20*log10(abs(fft(wx,2*numpar)));
      mo(:,frame) = tmp(1:numpar);
   elseif feat == 'cps'        % cepstral geglaettetes spektrum
      cepwin = numpar;
      cep = rceps(wx);
      tmp = 20/log(10)*real(fft(cep(1:cepwin),2*winlen));
      mo(:,frame) = tmp(1:winlen);
   end
end









