function f0 = getF0s(v, spec, rawSpec, thrs, upperF0Limit)
%struct array f0 = getF0s(v, spec, rawSpec [, thrs, upperF0Limit])
% 
% spec: preprocessed spectrum vector
% rawSpec: unchanged spectrum to obtain true amplitudes
% thrs: thresold for normalized amplitude (default 0.25)
% upperF0Limit: for debug purpose
%
% f0 : struct containing F0's frequencies, indices and amplitudes 

global opt

if nargin<5, upperF0Limit=opt.highestF ; end    
if nargin<4, thrs=opt.thrsF0 ; end    

% local definitions
dInd=6;
interpFac=16;

 % select only indices within note range
lowestInd=round(opt.lowestF/v.fMax*v.fLen);
highestInd=round(upperF0Limit/v.fMax*v.fLen);
 % for proper indices
if (dInd>lowestInd-1), lowestInd=dInd+1; end

subInd=lowestInd:highestInd;
toobigInd=find(subInd>size(spec,1));
subInd=setdiff(subInd, subInd(toobigInd));

subSpec=spec(subInd);

offsInd=lowestInd-1;

f0(1).freq=0;
f0(1).ind=1;
f0(1).a=0;

lastAmp=1;
i=1;
while (lastAmp>thrs)&(i<=6)
    
    % get next maximum
    [aTmp, subF0indTmp]=max(subSpec); 

    F0indTmp = subF0indTmp+offsInd;
    F0Tmp = F0indTmp*v.fMax/v.fLen;
    % get better frequency and amplitude with interpolation
    % wACF is used because ACF showed to be more exact than a preprocessed ACF / CEACF

    rsSpec=interp(abs(rawSpec(F0indTmp-dInd:F0indTmp+dInd)),interpFac,dInd);

    [aTmp2 tmpInd]=max(rsSpec);
    rsF0indTmp=(F0indTmp-dInd)+round(tmpInd/interpFac);
    rsF0Tmp=(F0indTmp-dInd+tmpInd/interpFac)*v.fMax/v.fLen;

      % erase this max within at least a 1/4 tone
    
      % in subSpec  
    kill=floor(F0Tmp/(2^(1/24))/v.fMax*v.fLen):ceil(F0Tmp*(2^(1/24))/v.fMax*v.fLen);
      % shift it for subSpec
    kill=kill-offsInd;
    goodKillInd=find(kill>0 & kill<=length(subSpec));
    kill=kill(goodKillInd);
    subSpec(kill)=zeros(1,length(kill));

      % and in rawSpec (this is necessary because of possibly including this max when interpolating!)
    kill=floor(rsF0Tmp/(2^(1/24))/v.fMax*v.fLen):ceil(rsF0Tmp*(2^(1/24))/v.fMax*v.fLen);
    goodKillInd=find(kill>0 & kill<=length(rawSpec));
    kill=kill(goodKillInd);
    rawSpec(kill)=zeros(1,length(kill));

    if ((aTmp>thrs)&(opt.lowestF<rsF0Tmp)&(rsF0Tmp<upperF0Limit))
 	if (length(intersect([rsF0Tmp], [f0.freq]))>0), continue; end
        %save F0
        f0(i).freq=rsF0Tmp;
        f0(i).ind=round(rsF0Tmp/v.fMax*v.fLen);
        f0(i).a=aTmp2;    
	i=i+1;
    end
    lastAmp=aTmp;
end    
