function specMSE = compareEnvelope(f0,specEnv)
% specMSE = compareEnvelope(f0,specEnv)
% 
% compares f0's harmonics with model envelope
% a reliaility-weighted MSE is returned
% 
global opt sw
global plotLineOrder

numCells=cellfun('ndims', specEnv);

for i=1:numCells
  if (length(f0.harmInds)<1), MSE=inf; continue; end
   % distance to model envelope
  harmDist=20*log10(abs(f0.harmAmp)) - specEnv{i}(f0.harmInds)';

   % subtract mean 
   % we suppose that the sum of all errors due to overlaps is 0
  harmDist=harmDist-mean(harmDist);

   % square and weight with reliability
  harmDistSq=(harmDist.^2).*f0.reliab';

  specMSE(i,1)=sum(harmDistSq)/sum(f0.reliab);

end

if (sw.DebugMode==1)
	global var
        specMSE
	figure(23)
        subplot(211)
        for i=1:numCells
          plot(var.f,specEnv{i}, plotLineOrder(i));
	  hold on
        end
	points=20*log10(abs(f0.harmAmp));
	points=points-mean(points)
	plot(f0.harmFreqs,points, 'r*')
	
	hold off	
        title(strcat('Envelope fitting for F0:',num2str(f0.harmFreqs(1))));
	legend('sax','nosax','Harmonics')
	xlabel('f')
	ylabel('|F(f)| [dB]')

        subplot(212)
	plot(f0.harmFreqs,f0.reliab, 'k*')
	axis([0 6000 0 1])
	xlabel('f')
	ylabel('reiability')
	title('reliabilities due to overlapping with other F0''s');

	%% print to file
	set(gcf, 'PaperPosition', [1 3 7 7]);
	print -depsc2 compareModels.eps

end
