function [x]=istft(X, ws, hop, L, trim)
%ISTFT : Inverse short time Fourier transform
%
%function [x]=istft(X, ws, hop, L, trim)
%
% input:
%  X   : specgram of signal (cell array for multichannel signals)
%  ws  : synthesis window
%  hop : hop size (default length(ws)/2 )
%  L   : length of ifft's (default 2*(rowcount(X)-1) )
%  trim: trim reconstructed signal (default 0, use 1 if stft was
%        used with padding to allow perfect reconstruction)
%
% output
%  x : reconstructed real signal(s)
%
%

% Make sure input specgram(s) are in a cell array

if ~iscell(X), 
  X={X};
end
N=length(X);      % Number of channels, 1=mono, 2=stereo, etc
[F,T]=size(X{1}); % Number of 'bins' in Frequency and Time


if nargin<5, trim=0; end
if nargin<4, L=(size(X{1},1)-1)*2; end  % Length of (i)fft
Lw=length(ws);                          % Length of window
if nargin<3, hop=Lw/2; end
x=zeros(Lw+(T-1)*hop,N);

%c='gbrm';
%figure(3);subplot(111);plot(1);

for k=1:N,
  X{k}(1,:)=X{k}(1,:)/2;
  X{k}(end,:)=X{k}(end,:)/2;
  for t=1:T
    tt=[1:Lw]+(t-1)*hop;
    tmp=2*real(ifft(X{k}(:,t),L));
    x(tt,k)=x(tt,k)+tmp(1:Lw).*ws(:);

%    subplot(311);
%    plot(tt,tmp.*ws,c(rem(t,4)+1));hold on;
%    subplot(312);
%    plot(tt,tmp,c(rem(t,4)+1));hold on;
%    subplot(313);
%    plot(x(:,k));
%    input('');
  end;
end;

if trim,
  pad=length(ws)-hop;
  x=x(pad+1:end-pad,:);
end
