function snd = prepareData(str)
% snd = prepareData(str)
%
% str: Sample to load, i.e. 'synth','chris','mobetter'....see code for more samples
% snd: struct containing audio data and parameters
%

global opt

switch str
case 'synth'
    [snd.stereo snd.mono]=testSynth   %data in stereo
case 'chris'
    [snd.stereo snd.mono]=reshapeWav('chrispotter-sample.wav',0,inf);
case 'mobetter'
    [snd.stereo snd.mono]=reshapeWav('mobetterblues.wav',0,20);
case 'invocation'
    [snd.stereo snd.mono]=reshapeWav('invocation.wav',20, 30);
case 'invocation-bass-clipped'
    % 7:40-8:00
    [snd.stereo snd.mono]=reshapeWav('invocation.wav',460, 480, 1);
case 'nino-bass'
    %  0:00-0:07 
    [snd.stereo snd.mono]=reshapeWav('el_nino.wav',0, 7);	
case 'nino-pianobass'
	%75s piano solo with bass 4:15-5:30
    [snd.stereo snd.mono]=reshapeWav('el_nino.wav',255, 330); 
case 'amorous-piano-clipped'
    %  4:50-5:00 =290-300
    [snd.stereo snd.mono]=reshapeWav('amorouscat.wav',290, 300,1);
case 'amorous-melody'
    %  
    [snd.stereo snd.mono]=reshapeWav('amorouscat.wav',25, 36);
case 'piano-range'
    [snd.stereo snd.mono]=reshapeWav('piano-881harmo_arpege.wav',3, 9);
case 'amorous'
    %  4:50-5:00 =290-300
    [snd.stereo snd.mono]=reshapeWav('amorouscat.wav',19, 29);
case 'nino'
    %  0:10-0:19 
    [snd.stereo snd.mono]=reshapeWav('el_nino.wav',10, 19);
case 'sax-range'
    [snd.stereo snd.mono]=reshapeWav('sax-range-forte-Bb-A-tuned.wav',0,inf);
case 'sax-range-clipped'
    [snd.stereo snd.mono]=reshapeWav('sax-range-forte-Bb-A-tuned.wav',0,inf,1);
case 'sax-chromatic'
    [snd.stereo snd.mono]=reshapeWav('sax-range-chromatic-Bb-G.wav',0,inf);
case 'sax-overtone'
    [snd.stereo snd.mono]=reshapeWav('sax-overtone.wav',0,inf);
case 'sax-range-freely'
    [snd.stereo snd.mono]=reshapeWav('sax-range-freely.wav',0,inf);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%    
% bundles of data

case 'saxmodel'
  	%34s
    [stereo{1} mono{1}]=reshapeWav('sax-range-forte-Bb-A-tuned.wav',0,inf);
    	%11s
    [stereo{2} mono{2}]=reshapeWav('sax-irgendwas.wav',0,inf);
    	%15s
    [stereo{3} mono{3}]=reshapeWav('sax-range-freely.wav',0,inf);
    	%31s
    [stereo{4} mono{4}]=reshapeWav('sax-range-chromatic-Bb-G.wav',0,inf);

    fill=zeros(opt.windowSize,2);
    snd.stereo=[stereo{1};fill;stereo{2};fill;stereo{3};fill;stereo{4}];
    snd.mono=[mono{1};fill(:,1);mono{2};fill(:,1);mono{3};fill(:,1);mono{4}];
case 'nonsaxmodel' 
	%bass
	%16s bass solo intro
    [stereo{1} mono{1}]=reshapeWav('el_nino.wav',0, 16); 
	%75s piano solo with bass 4:15-5:30
    [stereo{5} mono{5}]=reshapeWav('el_nino.wav',255, 330); 
    	%20s
    %[stereo{2} mono{2}]=reshapeWav('invocation.wav',460, 480, 1);
	%piano
 	%6s
    [stereo{3} mono{3}]=reshapeWav('piano-881harmo_arpege.wav',3, 9);
    	%37s
    %[stereo{3} mono{3}]=reshapeWav('piano-blue_dove.wav',0, inf); 
        %28s  4:37-5:05 =277-305
    [stereo{4} mono{4}]=reshapeWav('amorouscat.wav',277, 305);
   	%17s 2:15 - 2:32
    [stereo{6} mono{6}]=reshapeWav('mobetterblues.wav',135, 152);

    fill=zeros(5/4*opt.windowSize,2);
    snd.stereo=[stereo{1};fill;stereo{4};fill;stereo{3};fill;stereo{5};fill;stereo{6}];   
    snd.mono=[mono{1};fill(:,1);mono{4};fill(:,1);mono{3};fill(:,1);mono{5};fill(:,1);mono{6}]; 
    
    
case 'pianomodel'
	%6s
    [stereo{1} mono{1}]=reshapeWav('piano-881harmo_arpege.wav',3, 9);
    	%37s
    [stereo{3} mono{3}]=reshapeWav('piano-blue_dove.wav',0, inf); 
        %28s  4:37-5:05 =277-305
    [stereo{2} mono{2}]=reshapeWav('amorouscat.wav',277, 305);
    fill=zeros(opt.windowSize,2);
    snd.stereo=[stereo{1};fill;stereo{2}];
    snd.mono=[mono{1};fill(:,1);mono{2}];

end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%5
% prepare useful parameters

snd.var.f=[0:opt.fftSize/2-1]'*opt.samplFreq/opt.fftSize;
snd.var.fLen=length(snd.var.f);
snd.var.fMax=max(snd.var.f);

snd.var.cepAx=0:1/opt.samplFreq:opt.windowSize/2/opt.samplFreq-1/opt.samplFreq; %rceps independent of fftSize

snd.var.t=[0:opt.windowHop/opt.samplFreq:(size(snd.mono,1)-opt.windowSize)/opt.samplFreq];
snd.var.tLen = length(snd.var.t);
snd.var.tMax=max(snd.var.t);
