function [X,f,t]=stft(x, wa, hop, L, pad, fs)
%STFT  : Short time Fourier transform
%
%function [X,f,t]=stft(x, wa, hop, L, pad, fs)
%
% input:
%  x   : input signals (column vectors)
%  wa  : analysis window
%  hop : hop size (default length(wa)/2 )
%  L   : length of fft's (default length(wa))
%  pad : zeropad before and after signal (to get perfect
%        reconstruction at beginning and end)
%  fs  : sampling frequency (default 44100)
%
% output
%  X : stft of x (specgrams) (cell array for multichannel x)
%  f : frequency axis
%  t : time axis
%
%

if nargin<6, fs=44100; end
if nargin<5, pad=1; end
if nargin<4, L=length(wa); end
if nargin<3, hop=length(wa)/2; end

if pad,
  padding=zeros(length(wa)-hop,1);
else
  padding=[];
end

if ~iscell(x)
  % make sure input signals are in column vectors
  if size(x,1)<size(x,2), x=x.'; end

  N=size(x,2);
  X=cell(1,N);
  for k=1:N,
    [X{k},f,t]=specgram([padding;x(:,k);padding], L, fs, wa, length(wa)-hop);
  end;
else
  N=length(x);
  X=cell(1,N);
  f=cell(1,N);
  t=cell(1,N);
  for k=1:N,
    [X{k},f{k},t{k}]=specgram([padding;x{k};padding], L, fs, wa, length(wa)-hop);
  end;
end  
