function [wa,ws]=winFct(L,w,M,pad)
%WIN   : generate windows (analysis/synthesis) that can give perfect reconstruction OLA with STFT
%
%function [wa,ws]=win(L,w,M,pad)
%
% inputs: 
%  L : length of window
%  w : windowing function, see code for details
%  M : length of window including zeropadding
% pad: zeropadding (-1='pre', 0='both', 1='post') default 0
%
% outputs:
%  wa : analysis window
%  ws : synthesis window
% 
if nargin<4, pad=0; end
if nargin<3, M=L; end
if nargin<2, w=1; end

pre=[];
post=[];
padlength=M-L;
if padlength>0,
  switch pad,
    case {0, 'both'}
      pre=zeros(1,floor(padlength/2));
      post=zeros(1,ceil(padlength/2));
    case {-1, 'before', 'pre'}
      pre=zeros(1,padlength);
    case {1, 'after', 'post'}
      post=zeros(1,padlength);
    otherwise
      error(['unknown pad method : ' num2str(pad)]);
  end
end

% windowing functions:
% w<0 : windows where w(l)=w(M-l)
%       filtering with ha, and then hs, gives same result as filtering 
%       with h, but introduces one delay extra (leading 0 in window)
% w>0 : windows where w(l)=w(M-1-l);
switch w
  case -1,
    % wa=ws=sqrt(raised cosine)
    wa=[pre sqrt((1-cos(2*pi*([0:L-1])/L))/2) post].';
    ws=wa;
  case 1,
    % wa=ws=sqrt(raised cosine)
    wa=[pre sqrt((1-cos(2*pi*([0:L-1]+0.5)/L))/2) post].';
    ws=wa;
  case 2,
    % wa=raised cosine, ws=rectangular
    wa=[pre (1-cos(2*pi*([0:L-1]+.5)/L))/2 post].';
    ws=ones(M,1);
  case 3,
    % wa=rectangular, ws=raised cosine
    wa=ones(M,1);
    ws=[pre (1-cos(2*pi*([0:L-1]+.5)/L))/2 post].';
  case 4,
    % wa=ws=rectangular
    wa=[pre ones(1,L) post].';
    ws=ones(M,1);
end

